Index: src/x64/macro-assembler-x64.h |
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h |
index 90d9f52850eb5b0c35dc41982dae02736c593f9f..d5a028c8409d088c260783ff50bd022d3829a11e 100644 |
--- a/src/x64/macro-assembler-x64.h |
+++ b/src/x64/macro-assembler-x64.h |
@@ -1367,9 +1367,9 @@ class MacroAssembler: public Assembler { |
Register filler); |
// Emit code for a flooring division by a constant. The dividend register is |
// unchanged, the result is in rdx, and rax gets clobbered. |
- void FlooringDiv(Register dividend, int32_t divisor); |
+ void TruncatingDiv(Register dividend, int32_t divisor); |
// --------------------------------------------------------------------------- |
// StatsCounter support |
@@ -1367,9 +1367,9 @@ class MacroAssembler: public Assembler { |
Register filler); |
- // Emit code for a flooring division by a constant. The dividend register is |
+ // Emit code for a truncating division by a constant. The dividend register is |
// unchanged, the result is in rdx, and rax gets clobbered. |